@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2005 Mekensleep
+# Copyright (C) 2005, 2006 Mekensleep
 #
 # Mekensleep
 # 24 rue vieille du temple
@@ -25,25 +25,19 @@
 #
 from os.path import exists
 
+import pygame
+
 from twisted.internet import reactor
 
-from pokerengine.pokerchips import *
 from pokernetwork.pokerpackets import *
 from pokerclient2d import pokeranimation2d
+from pokerengine.pokerchips import PokerChips
 
 from pokerui.pokerdisplay import PokerDisplay
 
 import gtk
 import gtk.glade
 
-def chips2int(chips):
-    total = 0
-    while chips:
-        value = chips.pop(0)
-        count = chips.pop(0)
-        total += value * count
-    return total
-
 class PokerPlayer2D:
     def __init__(self, player, table):
         self.table = table
@@ -78,14 +72,12 @@ class PokerPlayer2D:
         self.name.modify_fg(gtk.STATE_NORMAL, color)
 
     def updateChips(self, bet, money):
-        bet = chips2int(bet)
-        money = chips2int(money)
         if bet > 0:
-            self.bet.set_text(str(bet))
+            self.bet.set_text(PokerChips.tostring(bet))
             self.bet.show()
         else:
             self.bet.hide()
-        self.money.set_text(str(money))
+        self.money.set_text(PokerChips.tostring(money))
 
     def updateCards(self):
         game = self.table.game
@@ -178,6 +170,12 @@ class PokerTable2D:
                 seat.show()
         self.glade.get_widget("quit").show()
         self.glade.get_widget("rebuy").show()
+        self.glade.get_widget("raise_increase").show() # 1x1 button used for accelerators
+        self.glade.get_widget("raise_decrease").show() # 1x1 button used for accelerators
+        self.glade.get_widget("raise_increase_bb").show() # 1x1 button used for accelerators
+        self.glade.get_widget("raise_decrease_bb").show() # 1x1 button used for accelerators
+        self.glade.get_widget("raise_pot").show() # 1x1 button used for accelerators
+        self.glade.get_widget("raise_half_pot").show() # 1x1 button used for accelerators
         self.updateTableStatus()
         self.glade.get_widget("table_status").show()
         
@@ -219,6 +217,16 @@ class PokerTable2D:
         if packet.type == PACKET_POKER_TABLE_DESTROY:
             self.deleteTable()
 
+        elif packet.type == PACKET_POKER_SELF_IN_POSITION:
+            pass
+#            glade_file = display.datadir + "/interface/interface2d.glade"
+#            glade = gtk.glade.XML(fname = glade_file, root = "table_action_dialog")
+#            class dialog_actions:
+#                def on_button2_clicked(self, button):
+#                    glade.get_widget("table_action_dialog").hide()
+#
+#            glade.signal_autoconnect(dialog_actions())
+            
         elif packet.type == PACKET_POKER_PLAYER_ARRIVE:
             self.serial2player[packet.serial] = PokerPlayer2D(packet, self)
             if packet.serial == self.display.protocol.getSerial():
@@ -252,6 +260,9 @@ class PokerTable2D:
         elif packet.type == PACKET_POKER_BET_LIMIT:
             self.bet_limit = packet
 
+        elif packet.type == PACKET_POKER_HIGHEST_BET_INCREASE:
+            self.display.updateRaiseRange(selected_amount = None)
+
         elif packet.type == PACKET_POKER_DEALER:
             self.dealer_buttons[packet.dealer].show()
             if packet.previous_dealer >= 0:
@@ -260,7 +271,7 @@ class PokerTable2D:
         elif packet.type == PACKET_POKER_POT_CHIPS:
             pots = self.game.getPots()
             pot = self.pots[packet.index]
-            pot.set_label(str(pots['pots'][packet.index][0]))
+            pot.set_label(PokerChips.tostring(pots['pots'][packet.index][0]))
             pot.show()
 
         elif packet.type == PACKET_POKER_CHIPS_POT2PLAYER:
@@ -305,10 +316,33 @@ class PokerTable2D:
 class PokerDisplay2D(PokerDisplay):
     def __init__(self, *args, **kwargs):
         PokerDisplay.__init__(self, *args, **kwargs)
-        self.verbose = self.settings.headerGetInt("/settings/@verbose")
-        self.datadir = self.settings.headerGet("/settings/data/@path")
+        self.settings.notifyUpdates(self.settingsUpdated)
+        self.settingsUpdated(self.settings)
         self.id2table = {}
 
+    def __del__(self):
+        pygame.mixer.quit()
+
+    def settingsUpdated(self, settings):
+        self.verbose = settings.headerGetInt("/settings/@verbose")
+        self.datadir = settings.headerGet("/settings/data/@path")
+        self.event2sound = None
+        if ( settings.headerGet("/settings/sound") == "yes" or
+             settings.headerGet("/settings/sound") == "on" ):
+            sounddir = settings.headerGet("/settings/data/@sounds")
+            #
+            # Load event to sound map
+            #
+            self.event2sound = {}
+            for (event, file) in self.config.headerGetProperties("/sequence/sounds")[0].iteritems():
+                soundfile = sounddir + "/" + file
+                if exists(soundfile):
+                    pygame.mixer.init()
+                    sound = pygame.mixer.Sound(sounddir + "/" + file)
+                    self.event2sound[event] = sound
+                else:
+                    self.error(soundfile + " file does not exist")
+
     def message(self, string):
         print "[PokerDisplay2D] " + string
 
@@ -323,8 +357,18 @@ class PokerDisplay2D(PokerDisplay):
         x = ( interface.width - width ) / 2
         y = ( interface.height - height ) / 2
         interface.screen.put(window, x, y)
+        self.accelerators()
         window.show()
         
+    def accelerators(self):
+        action_group = gtk.AccelGroup()
+        for key in self.settings.headerGetProperties('/settings/keys/key'):
+            name = key['name']
+            letter = key['control_key']
+            if self.verbose > 1: self.message(name + " is bound to Ctrl+" + letter)
+            self.actions[name].add_accelerator("clicked", action_group, gtk.gdk.keyval_from_name(letter), gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+        self.factory.interface.window.add_accel_group(action_group)
+
     def init(self):
         settings = self.settings
         config = self.config
@@ -337,11 +381,18 @@ class PokerDisplay2D(PokerDisplay):
             "call": self.glade.get_widget("call"),
             "raise": self.glade.get_widget("raise"),
             "raise_range": self.glade.get_widget("raise_range"),
+            "raise_increase": self.glade.get_widget("raise_increase"),
+            "raise_decrease": self.glade.get_widget("raise_decrease"),
+            "raise_increase_bb": self.glade.get_widget("raise_increase_bb"),
+            "raise_decrease_bb": self.glade.get_widget("raise_decrease_bb"),
+            "raise_pot": self.glade.get_widget("raise_pot"),
+            "raise_half_pot": self.glade.get_widget("raise_half_pot"),
             "check": self.glade.get_widget("check"),
             "fold": self.glade.get_widget("fold"),
             }
         self.switch = self.glade.get_widget("switch")
         self.glade.signal_autoconnect(self)
+#        self.actions['check'].add_accelerator("clicked", gtk.AccelGroup(), gtk.gdk.keyval_from_name("p"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
 
         self.animations = pokeranimation2d.create(self.glade, config, settings)
         
@@ -377,21 +428,65 @@ class PokerDisplay2D(PokerDisplay):
         self.renderer.interactorSelected(PacketPokerCall(game_id = protocol.getCurrentGameId(),
                                                          serial = protocol.getSerial()))
 
+    def on_raise_increase_clicked(self, button):
+        #
+        # There seem to be a gtk bug when the slider displacement for a given
+        # value is less than a pixel. In this case the slider does not have to move
+        # which is normal. However, it seems to have a undesirable side effect : the
+        # displayed value is not updated.
+        #
+        range = self.actions['raise_range']
+        adjustment = range.get_adjustment()
+        range.set_value(range.get_value() + adjustment.get_property('step-increment'))
+
+    def on_raise_decrease_clicked(self, button):
+        range = self.actions['raise_range']
+        adjustment = range.get_adjustment()
+        range.set_value(range.get_value() - adjustment.get_property('step-increment'))
+
+    def on_raise_increase_bb_clicked(self, button):
+        game_id = self.protocol.getCurrentGameId()
+        bb = self.id2table[game_id].game.bigBlind()
+        if bb:
+            range = self.actions['raise_range']
+            range.set_value(range.get_value() + (bb / 100.0))
+
+    def on_raise_decrease_bb_clicked(self, button):
+        game_id = self.protocol.getCurrentGameId()
+        bb = self.id2table[game_id].game.bigBlind()
+        if bb:
+            range = self.actions['raise_range']
+            range.set_value(range.get_value() - (bb / 100.0))
+
+    def on_raise_pot_clicked(self, button):
+        game_id = self.protocol.getCurrentGameId()
+        bet_limit = self.id2table[game_id].bet_limit
+        range = self.actions['raise_range']
+        adjustment = range.get_adjustment()
+        range.set_value(min(adjustment.get_property('upper'), bet_limit.pot / 100.0))
+
+    def on_raise_half_pot_clicked(self, button):
+        game_id = self.protocol.getCurrentGameId()
+        bet_limit = self.id2table[game_id].bet_limit
+        range = self.actions['raise_range']
+        adjustment = range.get_adjustment()
+        range.set_value(min(adjustment.get_property('upper'), ( bet_limit.pot / 2.0 ) / 100.0))
+
     def on_raise_clicked(self, button):
         raise_range = self.actions["raise_range"]
         protocol = self.protocol
         self.renderer.interactorSelected(PacketPokerRaise(game_id = protocol.getCurrentGameId(),
                                                           serial = protocol.getSerial(),
-                                                          amount = int(raise_range.get_value())))
+                                                          amount = int(raise_range.get_value() * 100)))
 
     def on_raise_range_value_changed(self, raise_range):
-        value = int(raise_range.get_value())
+        value = int(raise_range.get_value() * 100)
         game_id = self.protocol.getCurrentGameId()
         bet_limit = self.id2table[game_id].bet_limit
         remainder = value % bet_limit.step
         if remainder:
             value -= remainder
-            raise_range.set_value(value)
+            raise_range.set_value(value / 100.0)
 
     def deleteTable(self, game_id):
         table = self.id2table[game_id]
@@ -406,60 +501,46 @@ class PokerDisplay2D(PokerDisplay):
         table = self.id2table[game_id]
 
         if not packet.style:
-            if packet.name == "shadowstacks":
-                self.actions["call"].hide()
-                self.actions["raise"].hide()
+            self.actions[packet.name].hide()
+            if packet.name == "raise":
                 self.actions["raise_range"].hide()
-            else:
-                self.actions[packet.name].hide()
             return
                 
-        if packet.name == "check" or packet.name == "fold":
+        if packet.name == "check" or packet.name == "fold" or packet.name == "call" or packet.name == "raise":
             action = self.actions[packet.name]
             action.show()
             action.set_label(packet.style)
-
-        elif packet.name == "shadowstacks":
-            action = self.actions["call"]
-            if game.canCall(serial):
-                action.show()
-                if packet.style == "enabled" or packet.style == "activated":
-                    action.set_label("Call")
-                elif packet.style == "scheduled" and packet.selection.type == PACKET_POKER_CALL:
-                    action.set_label("(Call)")
-                else:
-                    self.error("updateAction call: unexpected style " + packet.style)
-            else:
-                action.hide()
-
-            action = self.actions["raise"]
-            if game.canRaise(serial):
+            if packet.name == "raise":
                 range = self.actions['raise_range']
                 bet_limit = table.bet_limit
-                range.set_value(bet_limit.min)
+                range.set_value(bet_limit.min / 100.0)
                 if bet_limit.min != bet_limit.max:
-                    range.set_range(bet_limit.min, bet_limit.max)
-                    range.set_increments(bet_limit.step, bet_limit.step)
-                    if packet.selection and packet.selection.type == PACKET_POKER_RAISE:
-                        range.set_value(packet.selection.amount)
-                    else:
-                        range.set_value(bet_limit.min)
                     range.show()
+                    if packet.selection and packet.selection.type == PACKET_POKER_RAISE:
+                        self.updateRaiseRange(packet.selection.amount / 100.0)
+                    else:
+                        self.updateRaiseRange(bet_limit.min / 100.0)
                 else:
                     range.hide()
-                
-                if packet.style == "enabled" or packet.style == "activated":
-                    action.set_label("Raise")
-                elif packet.style == "scheduled" and packet.selection.type == PACKET_POKER_RAISE:
-                    action.set_label("(Raise)")
-                else:
-                    print "ERROR: updateAction raise: unexpected style " + packet.style
-                action.show()
-            else:
-                action.hide()
-            
+        else:
+            self.error("updateAction %s: unexpected name " % packet.name)
+
+    def updateRaiseRange(self, selected_amount):
+        range = self.actions['raise_range']
+        if range.get_property('visible'):
+            game_id = self.protocol.getCurrentGameId()
+            game = self.factory.getGame(game_id)
+            serial = self.protocol.getSerial()
+            table = self.id2table[game_id]
+
+            bet_limit = table.bet_limit
+            range.set_range(bet_limit.min / 100.0, bet_limit.max / 100.0)
+            range.set_increments(bet_limit.step / 100.0, bet_limit.step / 100.0)
+            if selected_amount:
+                range.set_value(selected_amount / 100.0)
+
     def render(self, packet):
-        if self.verbose > 3: print "PokerDisplay2D::render: " + str(packet)
+        if self.verbose > 3: self.message(str(packet))
 
         if packet.type == PACKET_QUIT:
             reactor.stop()
@@ -467,7 +548,22 @@ class PokerDisplay2D(PokerDisplay):
 
         if not self.protocol or not self.protocol.getCurrentGameId():
             return
-        
+
+        if self.event2sound:
+            soundfile = self.event2sound.get(PacketNames[packet.type], None)
+            playsound = False
+            if soundfile:
+                if ( packet.type == PACKET_POKER_TIMEOUT_WARNING or
+                     packet.type == PACKET_POKER_TIMEOUT_NOTICE ):
+                    if packet.serial == self.protocol.getSerial():
+                        playsound = True
+                else:
+                    playsound = True
+            if playsound:
+                pygame.mixer.init()
+                soundfile.play()
+                reactor.callLater(4, pygame.mixer.quit)
+            
         game = self.factory.packet2game(packet)
         if game:
             self.id2table[game.id].render(packet)
