@@ -1,5 +1,5 @@
-/* *
- * Copyright (C) 2005 Mekensleep
+/**
+ * Copyright (C) 2005, 2006 Mekensleep
  *
  *	Mekensleep
  *	24 rue vieille du temple
@@ -22,6 +22,7 @@
  *
  * Authors:
  *  Loic Dachary <loic@gnu.org>
+ *  Cedric Pinson <cpinson@freesheep.org>
  */
 
 #include <time.h>
@@ -33,6 +34,7 @@
 #include "interface_io.h"
 #include "dispatcher.h"
 
+extern enum lobby_tab_state g_lobby_tab_state;
 static GladeXML* s_tournaments_xml = 0;
 static GtkWidget*	s_tournaments_window = 0;
 static GtkLabel*	s_players_label = 0;
@@ -53,6 +55,9 @@ static GtkWidget*	s_lobby_tabs_window = 0;
 static GtkWidget*	s_cashier_button_window = 0;
 static GtkButton*	s_cashier_button = 0;
 
+static int		s_tournaments_window_shown = 0;
+static GtkLayout* s_screen = 0;
+
 static int can_register = 0;
 
 #define PAGE_REGULAR 0
@@ -66,6 +71,9 @@ static void clear_stores(void) {
 
 static void	close_tournaments(void)
 {
+	if (s_screen == NULL)
+		return;
+
   gtk_widget_hide(s_tournaments_window);
   gtk_widget_hide(s_tournament_info_window);
   gtk_widget_hide(s_lobby_tabs_window);
@@ -142,6 +150,7 @@ static void	on_tournament_list_treeview_selection_changed(GtkTreeSelection *tree
     g_warning("treeview_selection: unable to find active row");
 }
 
+
 static void	on_table_toggled(GtkWidget *widget, gpointer user_data)
 {
   (void) user_data;
@@ -153,6 +162,12 @@ static void	on_table_toggled(GtkWidget *widget, gpointer user_data)
     flush_io_channel();
   }
 }
+//bridge for lobby.c
+void tournament_on_table_toggled(GtkWidget *widget, gpointer user_data)
+{
+  on_table_toggled(widget, user_data);
+}
+
 
 static void	on_tourney_toggled(GtkWidget *widget, gpointer user_data)
 {
@@ -160,17 +175,22 @@ static void	on_tourney_toggled(GtkWidget *widget, gpointer user_data)
 
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
     const char* name = gtk_widget_get_name(widget);
+    set_string("tournaments");
+    set_string("refresh");
+    set_string(name);
+    flush_io_channel();
     if(!strcmp(name, "sit_n_go")) {
       gtk_notebook_set_current_page(s_notebook, PAGE_SIT_N_GO);
     } else if(!strcmp(name, "regular")) {
       gtk_notebook_set_current_page(s_notebook, PAGE_REGULAR);
     }
-    set_string("tournaments");
-    set_string("refresh");
-    set_string(name);
-    flush_io_channel();
   }
 }
+//bridge for lobby.c
+void tournament_on_tourney_toggled(GtkWidget *widget, gpointer user_data)
+{
+  on_tourney_toggled(widget, user_data);
+}
 
 static void	on_all_radio_clicked(GtkWidget* widget, gpointer data)
 {
@@ -185,7 +205,7 @@ static void	on_all_radio_clicked(GtkWidget* widget, gpointer data)
   }
 }
 
-static void	on_play_money_radio_clicked(GtkWidget* widget, gpointer data)
+static void	on_money_one_radio_clicked(GtkWidget* widget, gpointer data)
 {
   (void) data;
 
@@ -193,12 +213,12 @@ static void	on_play_money_radio_clicked(GtkWidget* widget, gpointer data)
     clear_stores();
     set_string("tournaments");
     set_string("refresh");
-    set_string("play");
+    set_string("money_one");
     flush_io_channel();
   }
 }
 
-static void	on_custom_money_radio_clicked(GtkWidget* widget, gpointer data)
+static void	on_money_two_radio_clicked(GtkWidget* widget, gpointer data)
 {
   (void) data;
 
@@ -206,7 +226,7 @@ static void	on_custom_money_radio_clicked(GtkWidget* widget, gpointer data)
     clear_stores();
     set_string("tournaments");
     set_string("refresh");
-    set_string("custom");
+    set_string("money_two");
     flush_io_channel();
   }
 }
@@ -227,6 +247,8 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
   static int s_selected_tournament = 0;
 
   if(init) {
+		s_screen = screen;
+
     s_tournaments_xml = g_tournaments_xml;
     s_tournaments_window = gui_get_widget(g_tournaments_xml, "tournaments_window");
     g_assert(s_tournaments_window);
@@ -320,8 +342,8 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
     s_players_label = GTK_LABEL(gui_get_widget(g_tournaments_xml, "players_label"));
     s_tournaments_label = GTK_LABEL(gui_get_widget(g_tournaments_xml, "tournaments_label"));
     GUI_BRANCH(g_tournaments_xml, on_all_radio_clicked);
-    GUI_BRANCH(g_tournaments_xml, on_play_money_radio_clicked);
-    GUI_BRANCH(g_tournaments_xml, on_custom_money_radio_clicked);
+    GUI_BRANCH(g_tournaments_xml, on_money_one_radio_clicked);
+    GUI_BRANCH(g_tournaments_xml, on_money_two_radio_clicked);
 
     s_tournament_info_window = gui_get_widget(g_tournament_info_xml, "tournament_info_window");
     g_assert(s_tournament_info_window);
@@ -348,14 +370,17 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
 
     s_lobby_tabs_window = gui_get_widget(g_lobby_tabs_xml, "lobby_tabs_window");
     g_assert(s_lobby_tabs_window);
+    gtk_window_set_title(s_lobby_tabs_window,"tournaments_lobby_tabs_window");
     if(screen) gtk_layout_put(screen, s_lobby_tabs_window, 0, 0);
     gtk_widget_set_size_request(s_lobby_tabs_window, gui_width(screen), -1);
+
     
     GUI_BRANCH(g_lobby_tabs_xml, on_table_toggled);
     GUI_BRANCH(g_lobby_tabs_xml, on_tourney_toggled);
 
     s_cashier_button_window = gui_get_widget(g_cashier_button_xml, "cashier_button_window");
     g_assert(s_cashier_button_window);
+    gtk_window_set_title(s_cashier_button_window,"tournaments_cashier_button_window");
     if(screen) gtk_layout_put(screen, s_cashier_button_window, 0, 0);
     s_cashier_button = GTK_BUTTON(gui_get_widget(g_cashier_button_xml, "cashier_button"));
     g_assert(s_cashier_button);
@@ -366,47 +391,54 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
 
   char* tag = get_string();
   if(!strcmp(tag, "show")) {
+    g_lobby_tab_state = tournament;
     /*
      * calculate windows position
      */
     int	screen_width = gui_width(screen);
     int	screen_height = gui_height(screen);
 
-    int	top_left_x = (screen_width - 900) / 2;
-    int	top_left_y = (screen_height - 500) / 2;
+    int	top_left_x = (screen_width - 1000) / 2;
+    int	top_left_y = (screen_height - 450) / 2;
 
-    {
-      static position_t position;
-      position.x = top_left_x + 350;
-      position.y = top_left_y;
-      gui_place(s_tournaments_window, &position, screen);
-    }
+    if (screen != NULL || s_tournaments_window_shown == 0)
+      {
 
-    {
-      static position_t position;
-      position.x = top_left_x;
-      position.y = top_left_y;
-      gui_place(s_tournament_info_window, &position, screen);
-    }
+				{
+					static position_t position;
+					position.x = screen_width - 610;
+					position.y = top_left_y;
+					gui_place(s_tournaments_window, &position, screen);
+				}
 
-    {
-      static position_t position;
-      position.x = 0;
-      position.y = 33;
-      gui_place(s_lobby_tabs_window, &position, screen);
-    }
+				{
+					static position_t position;
+					position.x = top_left_x;
+					position.y = top_left_y;
+					gui_place(s_tournament_info_window, &position, screen);
+				}
 
+				{
+					static position_t position;
+					position.x = 0;
+					position.y = 33;
+					gui_place(s_lobby_tabs_window, &position, screen);
+				}
+
+				{
+					static position_t position;
+					position.x = top_left_x;
+					position.y = top_left_y + 435;
+					gui_place(s_cashier_button_window, &position, screen);
+				}
+				s_tournaments_window_shown = 1;
+		
+			}
     {
       char* label = get_string();
       gtk_button_set_label(s_cashier_button, label);
       g_free(label);
     }
-    {
-      static position_t position;
-      position.x = top_left_x;
-      position.y = top_left_y + 400;
-      gui_place(s_cashier_button_window, &position, screen);
-    }
 
     s_selected_tournament = 0;
 
@@ -424,13 +456,13 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
     }
 
     {
-      char* custom_money = get_string();
+      char* currency_serial = get_string();
       char* button;
       GtkWidget* radio;
-      if(!strcmp(custom_money, "y")) {
-        button = "custom_money_radio";
-      } else if(!strcmp(custom_money, "y")) {
-        button = "play_money_radio";
+      if(!strcmp(currency_serial, "money_two")) {
+        button = "money_two_radio";
+      } else if(!strcmp(currency_serial, "money_one")) {
+        button = "money_one_radio";
       } else {
         button = "all_radio";
       }
@@ -441,9 +473,27 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
       s_disable_buttons = 0;
 
-      g_free(custom_money);
+      g_free(currency_serial);
     }
+
+    {
+      //moneyone
+      GtkWidget* sl = gui_get_widget(g_tournaments_xml, "money_one_radio");
+      char* label = get_string();
+      gtk_button_set_label(GTK_BUTTON(sl), label);
+      g_free(label);
+    }
+
+    {
+      //moneytwo
+      GtkWidget* sl = gui_get_widget(g_tournaments_xml, "money_two_radio");
+      char* label = get_string();
+      gtk_button_set_label(GTK_BUTTON(sl), label);
+      g_free(label);
+    }
+
   } else if(!strcmp(tag, "hide")) {
+    g_lobby_tab_state = none;
     close_tournaments();
 
   } else if(!strcmp(tag, "info")) {
@@ -513,9 +563,9 @@ int	handle_tournaments(GladeXML* g_tournaments_xml, GladeXML* g_tournament_info_
     can_register = get_int();
     char* label = "";
     if(can_register == 1)
-      label = "Register";
+      label = "REGISTER";
     else if(can_register == 0)
-      label = "Unregister";
+      label = "UNREGISTER";
     gtk_label_set_text(s_register_unregister_label, label);
     gtk_widget_set_sensitive(GTK_WIDGET(s_register_unregister_button), can_register != 2);
     {
