@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2004, 2005 Mekensleep
+# Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
 # 24 rue vieille du temple
@@ -28,9 +28,10 @@
 #
 from twisted.internet.protocol import Protocol, Factory
 from twisted.internet import reactor
-from twisted.python import dispatch
 from string import split, join, rstrip
 from time import time, strftime, gmtime
+from pokerengine.pokerchips import PokerChips
+from pokernetwork import dispatch
 
 INTERFACE_READY = "//event/poker3d/pokerinterface/ready"
 INTERFACE_GONE = "//event/poker3d/pokerinterface/gone"
@@ -46,6 +47,8 @@ INTERFACE_OUTFITS_PARAMETER = "//event/poker3d/pokerinterface/outfits_parameter"
 INTERFACE_OUTFITS_RANDOM = "//event/poker3d/pokerinterface/outfits_random"
 INTERFACE_OUTFITS = "//event/poker3d/pokerinterface/outfits"
 INTERFACE_YESNO = "//event/poker3d/pokerinterface/yesno"
+INTERFACE_MUCK = "//event/poker3d/pokerinterface/muck"
+INTERFACE_CHECK_WARNING = "//event/poker3d/pokerinterface/check_warning"
 INTERFACE_MESSAGE_BOX = "//event/poker3d/pokerinterface/message_box"
 INTERFACE_CHOOSER = "//event/poker3d/pokerinterface/chooser"
 INTERFACE_POST_BLIND = "//event/poker3d/pokerinterface/post_blind"
@@ -72,6 +75,10 @@ class PokerInterface(dispatch.EventDispatcher):
                 data = self.handleLobby(data[1:])
             elif type == "yesno":
                 data = self.handleYesNo(data[1:])
+            elif type == "muck":
+                data = self.handleMuck(data[1:])
+            elif type == "check_warning":
+                data = self.handleCheckWarning(data[1:])
             elif type == "hand_history":
                 data = self.handleHands(data[1:])
             elif type == "blind":
@@ -119,8 +126,8 @@ class PokerInterface(dispatch.EventDispatcher):
         self.command("login", "hide")
 
     def handleTournaments(self, data):
-        self.publishEvent(INTERFACE_TOURNAMENTS, data[:3])
-        return data[3:]
+        self.publishEvent(INTERFACE_TOURNAMENTS, data[:2])
+        return data[2:]
     
     def updateTournamentsPlayersList(self, can_register, players):
         register_map = { True: "1",
@@ -153,8 +160,8 @@ class PokerInterface(dispatch.EventDispatcher):
                     packet[selected_index] = str(current_tournament)
             self.command(*packet)
             
-    def showTournaments(self, cashier_label, page, custom_money):
-        self.command("tournaments", "show", cashier_label, page, custom_money)
+    def showTournaments(self, cashier_label, page, currency_serial, money_one_name, money_two_name):
+        self.command("tournaments", "show", cashier_label, page, currency_serial, money_one_name, money_two_name)
                 
     def hideTournaments(self):
         self.command("tournaments", "hide")
@@ -166,7 +173,9 @@ class PokerInterface(dispatch.EventDispatcher):
     def updateLobbyPlayersList(self, players):
         packet = [ "lobby", "players", str(len(players)) ]
         if len(players) > 0:
-            map(lambda player: packet.extend(map(lambda value: str(value), player)), players)
+            for player in players:
+                ( name, chips, flag ) = player
+                packet.extend((name, PokerChips.tostring(chips), str(flag)))
         self.command(*packet)
 
     def updateLobby(self, players_count, tables_count, game_id, file2name, my_tables, tables):
@@ -183,13 +192,13 @@ class PokerInterface(dispatch.EventDispatcher):
                      table.name,
                      file2name(table.betting_structure),
                      str(table.seats),
-                     str(table.average_pot),
+                     PokerChips.tostring(table.average_pot),
                      str(table.hands_per_hour),
                      str(table.percent_flop),
                      str(table.players),
                      str(table.observers),
                      str(table.waiting),
-                     str(table.timeout) )
+                     str(table.player_timeout) )
             variant2tables[table.variant].append(info)
 
         for (variant, tables) in variant2tables.iteritems():
@@ -201,8 +210,8 @@ class PokerInterface(dispatch.EventDispatcher):
 
         self.command('lobby', 'info', "Players: %d" % players_count, "Tables: %d" % tables_count)
             
-    def showLobby(self, cashier_label, page, custom_money):
-        self.command("lobby", "show", cashier_label, page, custom_money)
+    def showLobby(self, cashier_label, page, currency_serial, money_one_name, money_two_name):
+        self.command("lobby", "show", cashier_label, page, currency_serial, money_one_name, money_two_name)
                 
     def hideLobby(self):
         self.command("lobby", "hide")
@@ -230,18 +239,64 @@ class PokerInterface(dispatch.EventDispatcher):
             if count >= nparams: break
             count += 1
             definition = outfit['DEFINITIONS'][xpath]
+            definition_entries = definition.getEntries()
+            definition_preview = definition.getPreview()
+            definition_preview_type = definition.getPreviewType()
+            definition_text = definition.getText()
             if self.verbose > 1:
                 print "value %s - %s " % (xpath, value['value'])
-                print "definition %s" % definition['ids']
+#before                print "definition %s" % definition['ids']
+                print "definition %s" % definition_entries
                 print "slot_type %s" % slot_type
-            if value['value'] not in definition['ids']:
+            if value['value'] not in definition_entries:
                 print "WARNING Changing default value for %s because the default value is masked" % value['parameter']
-                value['value'] = definition['ids'][0]
-            index = definition['ids'].index(value['value'])
-            packet.extend((definition['text'], xpath, "0", str(len(definition['ids'])), str(index)))
-            packet.append(definition['preview_type'])
-            packet.append(str(len(definition['preview'])))
-            packet.extend(definition['preview'])
+                value['value'] = definition_entries[0]
+            index = definition_entries.index(value['value'])
+            packet.extend((definition_text, xpath, "0", str(len(definition_entries)), str(index)))
+            packet.append(definition_preview_type)
+            packet.append(str(len(definition_preview)))
+            packet.extend(definition_preview)
+        if self.verbose > 1: print "PokerInterfaceProtocol:showOutfits " + str(packet)
+        self.command(*packet)
+
+
+    def showOutfits2(self, sex, slot_number, slot_type, slot, outfit):
+        self.command("outfit", "show")
+        packet = [ "outfit", "set", sex, str(slot_number) ]
+        slot_value_index = slot.keys().index(outfit['NAME'])
+        packet.extend((slot_type, "0" ,str(len(slot)), str(slot_value_index)))
+        nparams = min(len(outfit['VALUES']), 4)
+
+        key = 'global_skin_hue/color_set'
+        if slot_type != 'head' and outfit['VALUES'].has_key(key) :
+            nparams = nparams - 1
+
+        packet.append(str(nparams))
+        count = 0
+        for (xpath, value) in outfit['VALUES'].iteritems():
+            if slot_type != 'head' and xpath == key:
+                continue
+
+            if count >= nparams: break
+            count += 1
+            definition = outfit['DEFINITIONS'][xpath]
+            definition_entries = definition.getEntries()
+            definition_preview = definition.getPreview()
+            definition_preview_type = definition.getPreviewType()
+            definition_text = definition.getText()
+            if self.verbose > 1:
+                print "value %s - %s " % (xpath, value['value'])
+#before                print "definition %s" % definition['ids']
+                print "definition %s" % definition_entries
+                print "slot_type %s" % slot_type
+            if value['value'] not in definition_entries:
+                print "WARNING Changing default value for %s because the default value is masked" % value['parameter']
+                value['value'] = definition_entries[0]
+            index = definition_entries.index(value['value'])
+            packet.extend((definition_text, xpath, "0", str(len(definition_entries)), str(index)))
+            packet.append(definition_preview_type)
+            packet.append(str(len(definition_preview)))
+            packet.extend(definition_preview)
         if self.verbose > 1: print "PokerInterfaceProtocol:showOutfits " + str(packet)
         self.command(*packet)
 
@@ -310,6 +365,10 @@ class PokerInterface(dispatch.EventDispatcher):
             self.clearCallbacks(INTERFACE_CHOOSER)
         return data[1:]
         
+    def credits(self, message):
+        if self.verbose > 1: print "PokerInterfaceProtocol:credits %s" % message
+        self.command("credits", message)
+
     def messageBox(self, message):
         if self.verbose > 1: print "PokerInterfaceProtocol:messageBox %s" % message
         self.command("message_box", message)
@@ -337,8 +396,9 @@ class PokerInterface(dispatch.EventDispatcher):
     def handleBlind(self, data):
         if data[0] == "post":
             (tag, answer) = data[:2]
-            self.publishEvent(INTERFACE_POST_BLIND, answer)
-            self.clearCallbacks(INTERFACE_POST_BLIND)
+            if self.callbacks.has_key(INTERFACE_POST_BLIND):
+                self.publishEvent(INTERFACE_POST_BLIND, answer)
+                self.clearCallbacks(INTERFACE_POST_BLIND)
             data = data[2:]
         else:
             raise Exception("bad packet received from blind")
@@ -392,6 +452,37 @@ class PokerInterface(dispatch.EventDispatcher):
         self.clearCallbacks(INTERFACE_YESNO)
         return data[1:]
 
+    def muckShow(self):
+        if self.verbose > 1: print "PokerInterfaceProtocol:muckShow"
+        self.clearCallbacks(INTERFACE_MUCK)
+        self.command("muck", "show")
+        
+    def muckHide(self):
+        if self.verbose > 1: print "PokerInterfaceProtocol:muckHide"
+        self.clearCallbacks(INTERFACE_MUCK)
+        self.command("muck", "hide")
+        
+    def handleMuck(self, data):
+        response = data[0]
+        if (response != "show") and (response != "hide") and (response != "always"):
+            raise Exception("bad packet recieved from lobby")
+        self.publishEvent(INTERFACE_MUCK, response)
+        self.clearCallbacks(INTERFACE_MUCK)
+        return data[1:]
+
+    def checkWarningBox(self):
+        if self.verbose > 1: print "PokerInterfaceProtocol:checkWarningBox"
+        self.clearCallbacks(INTERFACE_CHECK_WARNING)
+        self.command("check_warning")
+
+    def handleCheckWarning(self, data):
+        response = data[0]
+        if (response != "fold") and (response != "check") and (response != "cancel"):
+            raise Exception("bad packet recieved from lobby")
+        self.publishEvent(INTERFACE_CHECK_WARNING, response)
+        self.clearCallbacks(INTERFACE_CHECK_WARNING)
+        return data[1:]
+
     def chatShow(self):
         self.command("chat", "show")
         
@@ -400,7 +491,10 @@ class PokerInterface(dispatch.EventDispatcher):
 
     def chatHistory(self, message):
         self.command("chat", "line", message)
-        
+
+    def chatHistoryReset(self):
+        self.command("chat", "reset")
+
     def chatHistoryShow(self):
         self.command("chat", "history", "show")
         
@@ -421,15 +515,16 @@ class PokerInterface(dispatch.EventDispatcher):
         self.command("buy_in", "hide")
         
     def buyInParams(self, minimum, maximum, legend, max_label):
-        packet = [ "buy_in", "params", str(minimum), str(maximum), legend, max_label ]
+        packet = [ "buy_in", "params", PokerChips.tostring(minimum), PokerChips.tostring(maximum), legend, max_label ]
         if self.verbose > 1: print "PokerInterfaceProtocol:requestBuyIn " + str(packet)
         self.command(*packet)
         
     def handleBuyIn(self, data):
         if self.verbose > 1: print "handleBuyIn: " + str(data)
         value = data[0]
-        self.publishEvent(INTERFACE_BUY_IN, value)
-        self.clearCallbacks(INTERFACE_BUY_IN)
+        if self.callbacks.has_key(INTERFACE_BUY_IN):
+            self.publishEvent(INTERFACE_BUY_IN, int(float(value) * 100))
+            self.clearCallbacks(INTERFACE_BUY_IN)
         return data[1:]
 
     def updateCashier(self, *messages):
@@ -442,8 +537,8 @@ class PokerInterface(dispatch.EventDispatcher):
         self.publishEvent(INTERFACE_CASHIER, data[0])
         return data[1:]
 
-    def showCashier(self, exit_label):
-        self.command("cashier", "show", "0", exit_label)
+    def showCashier(self, exit_label, money_one_name, money_two_name):
+        self.command("cashier", "show", "0", exit_label, money_one_name, money_two_name)
         
     def hideCashier(self):
         self.command("cashier", "hide", "0")
@@ -460,12 +555,10 @@ class PokerInterface(dispatch.EventDispatcher):
         auto_post = settings.headerGet("/settings/auto_post")
         remember_me = settings.headerGet("/settings/remember")
         muck = settings.headerGet("/settings/muck")
-        display = settings.headerGet("/settings/@display3d") == "yes" and "3d" or "2d"
         packet = []
         packet.extend(("menu", "set", "resolution", screen["width"] + "x" + screen["height"]))
         packet.extend(("menu", "set", "graphics", graphics))
         packet.extend(("menu", "set", "sound", sound))
-        packet.extend(("menu", "set", "display", display))
         packet.extend(("menu", "set", "fullscreen", screen["fullscreen"]))
         packet.extend(("menu", "set", "auto_post", auto_post))
         packet.extend(("menu", "set", "remember_me", remember_me))
