@@ -1,6 +1,6 @@
 <?php
 //
-// Copyright (C) 2005 Mekensleep
+// Copyright (C) 2005, 2006 Mekensleep
 //
 // Mekensleep
 // 24 rue vieille du temple
@@ -29,16 +29,21 @@ require_once 'common.php';
 
 $is_logged_in = $poker->isLoggedin();
 
+if($poker_error) print "<h3>" . $poker_error . "</h3>";
+
 hci_header();
 
 print "<h3>" . _get_string('comment') . "</h3>";
 
 if($is_logged_in) {
   $info = $poker->getPersonalInfo();
+  if($poker_error) print "<h3>" . $poker_error . "</h3>";
   echo '<h2>'.$infos['name'].'</h2>';
   echo '<!-- HOME IS LOGGED IN -->';
   echo '<a href="logout.php">logout</a><br>';
   echo '<a href="edit_account.php">Edit Account</a><br>';
+  echo '<a href="cash_in.php">Cash-In</a><br>';
+  echo '<a href="cash_out.php">Cash-Out</a><br>';
 } else {
   echo '<!-- HOME NOT LOGGED IN -->';
   echo '<a href="login.php">login</a><br>';
